@@ -21,9 +21,6 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "kwinglplatform.h"
 
 #include <QRegExp>
-#include <QStringList>
-#include <QDebug>
-#include <QOpenGLContext>
 #include <QOpenGLFunctions>
 
 #include <sys/utsname.h>
